Article class

Article class contains the parsed article data.

Constructors

Article({required String? title, required String? author, required int length, required String? excerpt, required String? siteName, required String? imageUrl, required String? faviconUrl, required String? content, required String? textContent, required String? language, required String? publishedTime})
Constructor for the Article class.

Properties

author → String?
Author of the article.
final
content → String?
HTML string of processed article content
final
excerpt → String?
Article description, or short excerpt from the content
final
faviconUrl → String?
Favicon URL of the site.
final
hashCode → int
The hash code for this object.
no setterinherited
imageUrl → String?
Image URL of the article.
final
language → String?
Content language
final
length → int
Length of the article, in characters.
final
publishedTime → String?
Published time of the article
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
siteName → String?
Site name where the article is published.
final
textContent → String?
text content of the article, with all the HTML tags removed
final
title → String?
Title of the article.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited