CArticle class final

Inheritance
Implemented types
Available extensions

Constructors

CArticle()

Properties

address → Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
author ↔ Pointer<Utf8>
getter/setter pair
content ↔ Pointer<Utf8>
HTML content
getter/setter pair
err ↔ Pointer<Utf8>
getter/setter pair
excerpt ↔ Pointer<Utf8>
getter/setter pair
favicon_url ↔ Pointer<Utf8>
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
image_url ↔ Pointer<Utf8>
getter/setter pair
language ↔ Pointer<Utf8>
getter/setter pair
length ↔ int
getter/setter pair
published_time ↔ Pointer<Utf8>
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
site_name ↔ Pointer<Utf8>
getter/setter pair
success ↔ int
getter/setter pair
text_content ↔ Pointer<Utf8>
text content
getter/setter pair
title ↔ Pointer<Utf8>
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited